@@ -1,8 +1,9 @@
+import os
 from setuptools import setup
 
 setup(
     name='lintest',
-    version='1.7.0.10',
+    version='1.7.2',
     author='Wang Lin',
     author_email='think_wl@163.com',
     packages=['lintest'],
@@ -14,7 +15,6 @@ setup(
         "setuptools",
         "urllib3",
         "PyMySQL",
-        "jsoncomparison",
         "chromedriver_autoinstaller"
     ]
 )
